@@ -7,15 +7,18 @@ import dateparser
 class Helpers(object):
     """GitHub Helpers class."""
 
-    def __init__(self, auth, github):
+    def __init__(self, auth=None, github=None):
         """Initialize a class instance."""
         self.auth = auth
         self.github = github
-        self.verbose = self.auth.verbose
+
+        self.verbose = False
+        if self.github:
+            self.verbose = self.github.verbose
 
     def get_org_members_full(self):
         """Return a list of org members with full details."""
-        firestore = self.github.firestore(self.auth)
+        firestore = self.github.firestore()
         firestore_members = firestore.get_members_dict()
 
         # assemble a list of members and their full records
@@ -54,7 +57,7 @@ class Helpers(object):
 
     def get_org_repos_full(self):
         """Return a list of org repos with full details."""
-        firestore = self.github.firestore(self.auth)
+        firestore = self.github.firestore()
         firestore_repos = firestore.get_repos_dict()
 
         # assemble a list of repos and their full records
@@ -90,7 +93,7 @@ class Helpers(object):
 
     def get_org_teams_full(self):
         """Return a list of org teams with full details."""
-        firestore = self.github.firestore(self.auth)
+        firestore = self.github.firestore()
         firestore_teams = firestore.get_teams_dict()
 
         # assemble a list of teams and their full records
@@ -157,13 +160,17 @@ class Helpers(object):
 
             # get team members
             members = []
+            # member_ids = []
             for m in self.github.get_team_members(tid):
-                members.append({'id': m['id'], 'login': m['login'].lower()})
+                # members.append({'id': m['id'], 'login': m['login'].lower()})
+                members.append(m['login'].lower())
+                # member_ids.append(m['id'])
 
             team = {
                 'id': tid,
                 'slug': slug,
                 'members': members,
+                # 'member_ids': member_ids,
             }
             teams_members.append(team)
             # firestore.db.collection('github_teams_members').document(str(tid)).set(team)
